@@ -142,8 +142,7 @@ class Namespace:
                 self.__dict__[name] = value
             elif opt_type == 10:  # number
                 value = option['value']  # type: ignore # Key is there
-                # This condition is written this way because 0 can be a valid float
-                if value is None or value == '':
+                if value is None:
                     self.__dict__[name] = float('nan')
                 else:
                     self.__dict__[name] = float(value)
